"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const MachineImage_1 = require("../MachineImage");
const MachineImageRepository_1 = require("../MachineImageRepository");
const MachineImageService_1 = require("../MachineImageService");
const driven_1 = require("../../../driven");
jest.mock('@jfrog-pipelines/configuration', () => {
    return {
        ConfigFactory: {}
    };
});
jest.mock('@jfrog-pipelines/logger', () => {
    return {
        LoggerFactory: {
            getLogger: jest.fn().mockReturnValue({
                info: jest.fn(),
                error: jest.fn(),
                debug: jest.fn(),
                trace: jest.fn(),
                warn: jest.fn()
            }),
            configure: jest.fn()
        }
    };
});
jest.mock('../MachineImageRepository');
jest.mock('../MachineImageService');
jest.mock('../../../driven/db/BuildPlaneImageDao');
jest.mock('promise');
const buildPlaneImage = {
    name: 'westus image for x86_64 Ubuntu_22.04',
    masterIntegrationId: 46,
    imageId: 'jfrog:pipelines-buildplane:x86_64-ubuntu_22_04:2.7.1:westus',
    region: 'westus',
    isAvailable: true,
    architecture: 'x86_64',
    operatingSystem: 'Ubuntu_22.04',
    metadataPropertyBag: {},
    isInternal: true
};
const imageResponse = [
    {
        name: 'westus image for x86_64 Ubuntu_22.04',
        provider: 'azureKeys',
        imageId: 'jfrog:pipelines-buildplane:x86_64-ubuntu_22_04:2.7.1:westus',
        region: 'westus',
        architecture: 'x86_64',
        os: 'Ubuntu_22.04',
        metadataPropertyBag: {
            type: 'published',
            plan: {
                name: 'x86_64-ubuntu_22_04',
                product: 'pipelines-buildplane',
                publisher: 'jfrog'
            }
        },
        createdAt: '2023-11-30'
    }
];
const mockGetBuildPlaneImages = jest.spyOn(MachineImageRepository_1.MachineImageRepository.prototype, 'getBuildPlaneImages');
mockGetBuildPlaneImages.mockResolvedValue(imageResponse);
const mockUpsert = jest.spyOn(driven_1.BuildPlaneImageDao.prototype, 'upsert');
mockUpsert.mockResolvedValue(buildPlaneImage);
const mockValidateUpsert = jest.spyOn(MachineImageService_1.MachineImageService.prototype, 'validateUpsert');
mockValidateUpsert.mockReturnValue(buildPlaneImage);
const mockAllSettled = jest.spyOn(Promise, 'allSettled');
mockAllSettled.mockResolvedValue([{ status: 'fulfilled', value: 'Mocked value 1' }]);
const machineImage = new MachineImage_1.MachineImage();
describe('Update build plane images in machine image dao', () => {
    it('should update valid images', async () => {
        await expect(machineImage.updateBuildPlaneImages()).resolves.toEqual(undefined);
    });
    it('should throw invalid images', async () => {
        mockValidateUpsert.mockImplementation(() => {
            throw new Error('Mocked error');
        });
        await expect(machineImage.updateBuildPlaneImages()).resolves.toEqual(undefined);
    });
    it('should allSettled  all invalid or valid images', async () => {
        mockAllSettled.mockResolvedValue([{ status: 'rejected', reason: new Error('Mocked error') }]);
        await expect(machineImage.updateBuildPlaneImages()).resolves.toEqual(undefined);
    });
});
//# sourceMappingURL=MachineImage.test.js.map