"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CreateJobCommand = void 0;
const node_assert_1 = require("node:assert");
const utility_1 = require("@jfrog-pipelines/utility");
class CreateJobCommand {
    constructor(job) {
        this.job = job;
    }
    validate() {
        throw new Error('Method not implemented.');
    }
    static create(job) {
        CreateJobCommand.validateNodePoolId(job);
        CreateJobCommand.validateStepId(job);
        CreateJobCommand.validateStepletInfo(job);
        CreateJobCommand.validateRunId(job);
        CreateJobCommand.validateAffinityGroup(job);
        CreateJobCommand.validateBuilderApiToken(job);
        CreateJobCommand.validateBuilderSetupApiToken(job);
        return new CreateJobCommand(job);
    }
    getJob() {
        return this.job;
    }
    static validateStepId(job) {
        if (!job.stepId) {
            throw new node_assert_1.AssertionError({
                message: 'stepId is required for CreateJobCommand, skipping not processing message'
            });
        }
    }
    static validateNodePoolId(job) {
        if (!job.nodePoolId) {
            throw new node_assert_1.AssertionError({
                message: 'nodePoolId is required for CreateJobCommand, skipping not processing message'
            });
        }
    }
    static validateStepletInfo(job) {
        if ((0, utility_1.isEmpty)(job.stepletInfo)) {
            throw new node_assert_1.AssertionError({
                message: 'stepletInfo is required for CreateJobCommand, skipping not processing message'
            });
        }
        for (const stepletInfo of job.stepletInfo) {
            this.validateStepletId(stepletInfo);
            this.validateImage(stepletInfo);
            this.validateTag(stepletInfo);
        }
    }
    static validateStepletId(stepletInfo) {
        if (!stepletInfo.stepletId) {
            throw new node_assert_1.AssertionError({
                message: 'stepletId is required for CreateJobCommand, skipping not processing message'
            });
        }
    }
    static validateImage(stepletInfo) {
        if (!stepletInfo.image) {
            throw new node_assert_1.AssertionError({
                message: 'image is required for CreateJobCommand, skipping not processing message'
            });
        }
    }
    static validateTag(stepletInfo) {
        if (!stepletInfo.tag) {
            throw new node_assert_1.AssertionError({
                message: 'tag is required for CreateJobCommand, skipping not processing message'
            });
        }
    }
    static validateRunId(job) {
        if (!job.runId) {
            throw new node_assert_1.AssertionError({
                message: 'runId is required for CreateJobCommand, skipping not processing message'
            });
        }
    }
    static validateAffinityGroup(job) {
        if (!job.affinityGroup) {
            throw new node_assert_1.AssertionError({
                message: 'affinityGroup is required for CreateJobCommand, skipping not processing message'
            });
        }
    }
    static validateBuilderSetupApiToken(job) {
        if (!job.builderSetupApiToken) {
            throw new node_assert_1.AssertionError({
                message: 'affinityGroup is required for CreateJobCommand, skipping not processing message'
            });
        }
    }
    static validateBuilderApiToken(job) {
        if (!job.builderApiToken) {
            throw new node_assert_1.AssertionError({
                message: 'affinityGroup is required for CreateJobCommand, skipping not processing message'
            });
        }
    }
}
exports.CreateJobCommand = CreateJobCommand;
//# sourceMappingURL=CreateJobCommand.js.map